seqtools.partition_sequence_cyclically_by_weights_exactly_without_overhang
==========================================================================

.. autofunction:: abjad.tools.seqtools.partition_sequence_cyclically_by_weights_exactly_without_overhang
